@@ -35,3 +35,6 @@ from .interop import HInteropError
 # in an ergonomic, consistent and readable way.
 from .python_interop import *
 from .numpy_interop import *
+# Additinaly import HALCON error constants as a module to the
+# halcon namespace.
+from . import errors
