@@ -57,6 +57,8 @@ __all__ = [
     'HTupleElementType',
     'HTupleType',
     'make_c_func_prototype',
+    'enable_utf8_error_replace',
+    'disable_utf8_error_replace',
 ]
 
 
@@ -413,8 +415,29 @@ def make_c_func_prototype(restype, *argtypes):
     return ctypes.CFUNCTYPE(restype, *argtypes)
 
 
+def enable_utf8_error_replace():
+    """
+    When decoding HALCON strings to Python strings, replace invalid UTF-8
+    characters. This is not recommended. Only use this option if
+    absolutely necessary.
+    """
+    global _utf8_error_mode
+    _utf8_error_mode = 'replace'
+
+
+def disable_utf8_error_replace():
+    """
+    When decoding HALCON strings to Python strings, raise an UnicodeError
+    exception if invalid UTF-8 characters are encountered.
+    This is the default behavior.
+    """
+    global _utf8_error_mode
+    _utf8_error_mode = 'strict'
+
+
 # --- Private Implementation Details ---
 
+_utf8_error_mode = 'strict'
 _is_32bit_win = os.name == 'nt' and sys.maxsize == (2**31 - 1)
 
 
@@ -811,7 +834,7 @@ def _htuple_element_to_python(
         if c_str_bytes is None:
             raise Exception('TODO What should be done here?')
 
-        return c_str_bytes.decode('utf-8')
+        return c_str_bytes.decode('utf-8', errors=_utf8_error_mode)
 
     raise HTupleConversionError(
         f'Unknown HTuple element type {element_type}'
