@@ -13,7 +13,7 @@ in this case hdevenginecpp.
 
 ************************************************************
 
-(c) 1996-2020 by MVTec Software GmbH
+(c) 1996-2022 by MVTec Software GmbH
 
 Software by: MVTec Software GmbH, www.mvtec.com
 """
@@ -477,9 +477,12 @@ class HDevEngine(object):
             ctypes.c_char_p(name.encode('utf8')),
             ctypes.byref(hkey)
         ))
-        return HObject._copy_from_key(hkey)
+        # Somewhat surprisingly HCenGetGlobalIconicVarObject returns a
+        # pointer, that owns the underlying HObject, so no copy should be done,
+        # otherwise this would be a memory leak.
+        return HObject(hkey)
 
-    def get_global_iconic_vector_var(self, name: str) -> TupleVectorType:
+    def get_global_iconic_vector_var(self, name: str) -> IconicVectorType:
         """
         Returns the value of a global iconic vector variable.
 
@@ -2054,9 +2057,9 @@ class HDevEmptyVector(object):
 # --- Exported Functions ---
 
 
-def HCkE(inital_error_code: int) -> None:
+def HCkE(initial_error_code: int) -> None:
     """Check the error number and raise exception if no ok."""
-    if inital_error_code == 2:  # C constant H_MSG_OK
+    if initial_error_code == 2:  # C constant H_MSG_OK
         return
 
     try:
@@ -2076,7 +2079,7 @@ def HCkE(inital_error_code: int) -> None:
             ctypes.byref(user_data_handle_ptr)
         )
 
-        # If a HDevEngine specific error occured inital_error_code is -1,
+        # If a HDevEngine specific error occurred initial_error_code is -1,
         # and error_code > 20000.
 
         category = category_ptr.value
@@ -2099,8 +2102,6 @@ def HCkE(inital_error_code: int) -> None:
             line_number=0,
             user_data=[]
         )
-    finally:
-        _hdevengine_lib.HCenReleaseLastException()
 
     raise HDevEngineError(
         error_code,
@@ -2466,7 +2467,10 @@ def _iconic_vec_elem_obj(
         ctypes.byref(hkey)
     ))
 
-    return HObject._copy_from_key(hkey)
+    # Somewhat surprisingly HCenGetObjectVectorElementObject returns a pointer,
+    # that owns the underlying HObject, so no copy should be done, otherwise
+    # this would be a memory leak.
+    return HObject(hkey)
 
 
 def _iconic_vec_elem_vec(
